@@ -32,14 +32,18 @@ class Config:
 
     defaults = {
         "qobuz": {
-            "enabled": True,
             "email": None,
             "password": None,
             "app_id": "",  # Avoid NoneType error
             "secrets": [],
         },
-        "tidal": {"enabled": True, "email": None, "password": None},
-        "deezer": {"enabled": True},
+        "tidal": {
+            "user_id": None,
+            "country_code": None,
+            "access_token": None,
+            "refresh_token": None,
+            "token_expiry": 0,
+        },
         "database": {"enabled": True, "path": None},
         "conversion": {
             "enabled": False,
@@ -120,10 +124,7 @@ class Config:
 
     @property
     def tidal_creds(self):
-        return {
-            "email": self.file["tidal"]["email"],
-            "pwd": self.file["tidal"]["password"],
-        }
+        return self.file["tidal"]
 
     @property
     def qobuz_creds(self):
