@@ -63,18 +63,21 @@ class MusicDL(list):
         :param source:
         :type source: str
         """
-        click.secho(f"Enter {capitalize(source)} email:", fg="green")
-        self.config.file[source]["email"] = input()
-        click.secho(
-            f"Enter {capitalize(source)} password (will not show on screen):",
-            fg="green",
-        )
-        self.config.file[source]["password"] = getpass(
-            prompt=""
-        )  # does hashing work for tidal?
+        if source == "qobuz":
+            click.secho(f"Enter {capitalize(source)} email:", fg="green")
+            self.config.file[source]["email"] = input()
+            click.secho(
+                f"Enter {capitalize(source)} password (will not show on screen):",
+                fg="green",
+            )
+            self.config.file[source]["password"] = getpass(
+                prompt=""
+            )  # does hashing work for tidal?
 
-        self.config.save()
-        click.secho(f'Credentials saved to config file at "{self.config._path}"')
+            self.config.save()
+            click.secho(f'Credentials saved to config file at "{self.config._path}"')
+        else:
+            raise Exception
 
     def assert_creds(self, source: str):
         assert source in ("qobuz", "tidal", "deezer"), f"Invalid source {source}"
@@ -82,7 +85,7 @@ class MusicDL(list):
             # no login for deezer
             return
 
-        if (
+        if source == "qobuz" and (
             self.config.file[source]["email"] is None
             or self.config.file[source]["password"] is None
         ):
@@ -98,9 +101,14 @@ class MusicDL(list):
         """
         for source, url_type, item_id in self.parse_urls(url):
             if item_id in self.db:
-                logger.info(f"{url} already downloaded, use --no-db to override.")
-                click.secho(f"{url} already downloaded, use --no-db to override.", fg='magenta')
-                break
+                logger.info(
+                    f"ID {item_id} already downloaded, use --no-db to override."
+                )
+                click.secho(
+                    f"ID {item_id} already downloaded, use --no-db to override.",
+                    fg="magenta",
+                )
+                continue
 
             self.handle_item(source, url_type, item_id)
 
@@ -138,7 +146,9 @@ class MusicDL(list):
             else:
                 item.download(**arguments)
 
-            self.db.add(item.id)
+            if self.db != []:
+                self.db.add(item.id)
+
             if self.config.session["conversion"]["enabled"]:
                 click.secho(
                     f"Converting {item!s} to {self.config.session['conversion']['codec']}",
@@ -178,6 +188,9 @@ class MusicDL(list):
                     self.config.file["qobuz"]["secrets"],
                 ) = client.get_tokens()
                 self.config.save()
+            elif client.source == 'tidal':
+                self.config.file['tidal'] = client.get_tokens()
+                self.config.save()
 
     def parse_urls(self, url: str) -> Tuple[str, str]:
         """Returns the type of the url and the id.
@@ -249,11 +262,13 @@ class MusicDL(list):
                 "{bit_depth} bit / {sampling_rate} Hz\n"
                 "Version: {version}"
             )
-            fields = (fname for _, fname, _, _ in Formatter().parse(fmt) if fname)
-            ret = fmt.format(**{k: media.get(k, "Unknown") for k in fields})
+        elif isinstance(media, Artist):
+            fmt = "{name}"
         else:
             raise NotImplementedError
 
+        fields = (fname for _, fname, _, _ in Formatter().parse(fmt) if fname)
+        ret = fmt.format(**{k: media.get(k, "Unknown") for k in fields})
         return ret
 
     def interactive_search(
